==> spip_2.0.8.orig.tar.gz: spip-2.0.8.orig/ecrire/lang/public_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => '&#20027;&#39029;',
'articles' => '&#25991;&#31456;',
'articles_auteur' => '&#35813;&#20316;&#32773;&#30340;&#25991;&#31456;',
'articles_populaires' => '&#28909;&#38376;&#25991;&#31456;',
'articles_rubrique' => '&#27492;&#26639;&#19979;&#30340;&#25991;&#31456;',
'aucun_article' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#25991;&#31456;',
'aucun_auteur' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#20316;&#32773;',
'aucun_site' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#31449;&#28857;',
'aucune_breve' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#31616;&#35201;',
'aucune_rubrique' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#19987;&#26639;',
'autres_breves' => '&#20854;&#23427;&#31616;&#35201;',
'autres_groupes_mots_clefs' => '&#20854;&#23427;&#20851;&#38190;&#35789;&#32452;',
'autres_sites' => '&#20854;&#23427;&#31449;&#28857;',

// B
'bonjour' => '&#24744;&#22909;',
'breves' => '&#31616;&#35201;',

// C
'commenter_site' => '&#35780;&#35770;&#31449;&#28857;',

// D
'date' => '&#26085;&#26399;',
'dernier_ajout' => '&#26368;&#26032;&#28155;&#20837;',
'dernieres_breves' => '&#26368;&#26032;&#31616;&#35201;',
'derniers_articles' => '&#26368;&#26032;&#25991;&#31456;',
'derniers_commentaires' => '&#26368;&#26032;&#35780;&#35770;',
'derniers_messages_forum' => '&#35770;&#22363;&#26368;&#36817;&#21457;&#34920;&#30340;&#28040;&#24687;',

// E
'edition_mode_texte' => '&#25991;&#26412;&#32534;&#36753;&#27169;&#24335;',
'en_reponse' => '&#22238;&#22797;:',
'en_resume' => '&#25688;&#35201;',
'envoyer_message' => '&#21457;&#36865;&#28040;&#24687;',
'espace_prive' => '&#31169;&#26377;&#21306;',

// F
'forum' => '&#35770;&#22363;',

// H
'hierarchie_site' => '&#31449;&#28857;&#23618;&#27425;',

// J
'jours' => '&#22825;',

// M
'meme_auteur' => '&#21516;&#19968;&#20316;&#32773;',
'meme_rubrique' => '&#21516;&#19968;&#19987;&#26639;',
'memes_auteurs' => '&#21516;&#19968;&#20316;&#32773;',
'message' => '&#28040;&#24687;',
'messages_forum' => '&#35770;&#22363;&#28040;&#24687;',
'messages_recents' => '&#26368;&#36817;&#35770;&#22363;&#28040;&#24687;',
'mots_clefs' => '&#20851;&#38190;&#35789;',
'mots_clefs_meme_groupe' => '&#21516;&#32452;&#20851;&#38190;&#35789;',

// N
'navigation' => '&#23548;&#33322;',
'nom' => '&#21517;&#23383;',
'nouveautes' => '&#26032;&#21464;&#21160;',
'nouveautes_web' => '&#26032;&#39029;&#38754;',
'nouveaux_articles' => '&#26032;&#25991;&#31456;',
'nouvelles_breves' => '&#26032;&#35201;&#38395;',

// P
'page_precedente' => '&#21069;&#19968;&#39029;',
'page_suivante' => '&#21518;&#19968;&#39029;',
'par_auteur' => '&#25353;&#29031;',
'participer_site' => '&#36890;&#36807;email&#27880;&#20876;&#24471;&#21040;&#35775;&#38382;&#30721;,&#24744;&#21487;&#20197;&#22312;&#26412;&#31449;&#28857;&#19978;&#24471;&#21040;&#19968;&#20010;&#27963;&#21160;&#21306;&#24182;&#21457;&#34920;&#24744;&#33258;&#24049;&#30340;&#25991;&#31456;.',
'plan_site' => '&#31449;&#28857;&#22320;&#22270;',
'popularite' => '&#28909;&#28857;',
'poster_message' => '&#21457;&#34920;&#28040;&#24687;',
'proposer_site' => '<NEW>Vous pouvez proposer un site &agrave; ajouter dans cette rubrique&nbsp;:',

// R
'repondre_article' => '&#22238;&#22797;&#25991;&#31456;',
'repondre_breve' => '&#22238;&#22797;&#31616;&#35201;',
'repondre_message' => '&#22238;&#22797;&#28040;&#24687;',
'resultats_recherche' => '&#25628;&#32034;&#32467;&#26524;',
'retour_debut_forums' => '&#36820;&#22238;&#35770;&#22363;&#39030;',
'rubrique' => '&#19987;&#26639;',
'rubriques' => '&#19987;&#26639;',

// S
'signatures_petition' => '&#31614;&#21517;',
'site_realise_avec_spip' => '&#20351;&#29992;SPIP&#24314;&#31435;&#30340;&#31449;&#28857;',
'sites_web' => '&#32593;&#31449;',
'sous_rubriques' => '&#23376;&#19987;&#26639;',
'suite' => '&#32487;&#32493;',
'sur_web' => '&#22312;&#32593;&#19978;',
'syndiquer_rubrique' => '&#32852;&#21512;&#35813;&#19987;&#26639;',
'syndiquer_site' => '&#32852;&#21512;&#25972;&#20010;&#31449;&#28857;',

// T
'texte_lettre_information' => '&#31449;&#28857;&#26102;&#20107;&#36890;&#35759;',
'texte_lettre_information_2' => '&#26412;&#23553;&#20449;&#32479;&#35745;&#33258;&#19979;&#36848;&#26102;&#38388;&#21457;&#34920;&#30340;&#25991;&#31456;&#21644;&#31616;&#35201;',

// V
'ver_imprimer' => '&#25171;&#21360;&#29256;&#26412;',
'voir_en_ligne' => '&#22312;&#32447;&#39044;&#35272;'
);

?>

==> spip_2.1.1.orig.tar.gz: spip-2.1.1/ecrire/lang/public_zh.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => '&#20027;&#39029;',
'article' => 'Article', # NEW
'articles' => '&#25991;&#31456;',
'articles_auteur' => '&#35813;&#20316;&#32773;&#30340;&#25991;&#31456;',
'articles_populaires' => '&#28909;&#38376;&#25991;&#31456;',
'articles_rubrique' => '&#27492;&#26639;&#19979;&#30340;&#25991;&#31456;',
'aucun_article' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#25991;&#31456;',
'aucun_auteur' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#20316;&#32773;',
'aucun_site' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#31449;&#28857;',
'aucune_breve' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#31616;&#35201;',
'aucune_rubrique' => '&#35813;&#22320;&#22336;&#19979;&#27809;&#26377;&#19987;&#26639;',
'auteur' => 'Auteur', # NEW
'autres' => 'Autres', # NEW
'autres_breves' => '&#20854;&#23427;&#31616;&#35201;',
'autres_groupes_mots_clefs' => '&#20854;&#23427;&#20851;&#38190;&#35789;&#32452;',
'autres_sites' => '&#20854;&#23427;&#31449;&#28857;',

// B
'bonjour' => '&#24744;&#22909;',
'breve' => 'Br&egrave;ve', # NEW
'breves' => '&#31616;&#35201;',

// C
'commenter_site' => '&#35780;&#35770;&#31449;&#28857;',
'copie_document_impossible' => 'Impossible de copier le document', # NEW

// D
'date' => '&#26085;&#26399;',
'dernier_ajout' => '&#26368;&#26032;&#28155;&#20837;',
'dernieres_breves' => '&#26368;&#26032;&#31616;&#35201;',
'derniers_articles' => '&#26368;&#26032;&#25991;&#31456;',
'derniers_commentaires' => '&#26368;&#26032;&#35780;&#35770;',
'derniers_messages_forum' => '&#35770;&#22363;&#26368;&#36817;&#21457;&#34920;&#30340;&#28040;&#24687;',
'documents_interdits_forum' => 'Documents interdits dans le forum', # NEW

// E
'edition_mode_texte' => '&#25991;&#26412;&#32534;&#36753;&#27169;&#24335;',
'en_reponse' => '&#22238;&#22797;:',
'en_resume' => '&#25688;&#35201;',
'envoyer_message' => '&#21457;&#36865;&#28040;&#24687;',
'espace_prive' => '&#31169;&#26377;&#21306;',

// F
'formats_acceptes' => 'Formats accept&#233;s : @formats@.', # NEW
'forum' => '&#35770;&#22363;',

// H
'hierarchie_site' => '&#31449;&#28857;&#23618;&#27425;',

// J
'jours' => '&#22825;',

// L
'lien_connecter' => 'Se connecter', # NEW

// M
'meme_auteur' => '&#21516;&#19968;&#20316;&#32773;',
'meme_rubrique' => '&#21516;&#19968;&#19987;&#26639;',
'memes_auteurs' => '&#21516;&#19968;&#20316;&#32773;',
'message' => '&#28040;&#24687;',
'messages_forum' => '&#35770;&#22363;&#28040;&#24687;',
'messages_recents' => '&#26368;&#36817;&#35770;&#22363;&#28040;&#24687;',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => '&#20851;&#38190;&#35789;',
'mots_clefs_meme_groupe' => '&#21516;&#32452;&#20851;&#38190;&#35789;',

// N
'navigation' => '&#23548;&#33322;',
'nom' => '&#21517;&#23383;',
'nouveautes' => '&#26032;&#21464;&#21160;',
'nouveautes_web' => '&#26032;&#39029;&#38754;',
'nouveaux_articles' => '&#26032;&#25991;&#31456;',
'nouvelles_breves' => '&#26032;&#35201;&#38395;',

// P
'page_precedente' => '&#21069;&#19968;&#39029;',
'page_suivante' => '&#21518;&#19968;&#39029;',
'par_auteur' => '&#25353;&#29031;',
'participer_site' => '&#36890;&#36807;email&#27880;&#20876;&#24471;&#21040;&#35775;&#38382;&#30721;,&#24744;&#21487;&#20197;&#22312;&#26412;&#31449;&#28857;&#19978;&#24471;&#21040;&#19968;&#20010;&#27963;&#21160;&#21306;&#24182;&#21457;&#34920;&#24744;&#33258;&#24049;&#30340;&#25991;&#31456;.',
'plan_site' => '&#31449;&#28857;&#22320;&#22270;',
'popularite' => '&#28909;&#28857;',
'poster_message' => '&#21457;&#34920;&#28040;&#24687;',
'proposer_site' => 'Vous pouvez proposer un site &agrave; ajouter dans cette rubrique&nbsp;:', # NEW

// R
'repondre_article' => '&#22238;&#22797;&#25991;&#31456;',
'repondre_breve' => '&#22238;&#22797;&#31616;&#35201;',
'repondre_message' => '&#22238;&#22797;&#28040;&#24687;',
'resultats_recherche' => '&#25628;&#32034;&#32467;&#26524;',
'retour_debut_forums' => '&#36820;&#22238;&#35770;&#22363;&#39030;',
'rubrique' => '&#19987;&#26639;',
'rubriques' => '&#19987;&#26639;',

// S
'signatures_petition' => '&#31614;&#21517;',
'site_realise_avec_spip' => '&#20351;&#29992;SPIP&#24314;&#31435;&#30340;&#31449;&#28857;',
'sites_web' => '&#32593;&#31449;',
'sous_rubriques' => '&#23376;&#19987;&#26639;',
'spam' => 'Spam', # NEW
'suite' => '&#32487;&#32493;',
'sur_web' => '&#22312;&#32593;&#19978;',
'syndiquer_rubrique' => '&#32852;&#21512;&#35813;&#19987;&#26639;',
'syndiquer_site' => '&#32852;&#21512;&#25972;&#20010;&#31449;&#28857;',

// T
'texte_lettre_information' => '&#31449;&#28857;&#26102;&#20107;&#36890;&#35759;',
'texte_lettre_information_2' => '&#26412;&#23553;&#20449;&#32479;&#35745;&#33258;&#19979;&#36848;&#26102;&#38388;&#21457;&#34920;&#30340;&#25991;&#31456;&#21644;&#31616;&#35201;',

// V
'ver_imprimer' => '&#25171;&#21360;&#29256;&#26412;',
'voir_en_ligne' => '&#22312;&#32447;&#39044;&#35272;',
'voir_squelette' => 'voir le squelette de cette page', # NE
);

?>
